@@ -961,7 +961,11 @@ class Quantile(AggFunc):
     arg_types = {"this": True, "quantile": True}
 
 
-class RegexLike(Func):
+class RegexpLike(Func):
+    arg_types = {"this": True, "expression": True}
+
+
+class RegexpSplit(Func):
     arg_types = {"this": True, "expression": True}
 
 
@@ -973,6 +977,10 @@ class SetAgg(AggFunc):
     pass
 
 
+class Split(Func):
+    arg_types = {"this": True, "expression": True}
+
+
 class Substring(Func):
     arg_types = {"this": True, "start": True, "length": False}
 
