@@ -63,10 +63,12 @@ class TokenType(AutoName):
     VARCHAR = auto()
     TEXT = auto()
     BINARY = auto()
+    BYTEA = auto()
     JSON = auto()
     TIMESTAMP = auto()
     TIMESTAMPTZ = auto()
     DATE = auto()
+    UUID = auto()
 
     # keywords
     ADD_FILE = auto()
@@ -130,6 +132,7 @@ class TokenType(AutoName):
     MAP = auto()
     MOD = auto()
     NULL = auto()
+    OFFSET = auto()
     ON = auto()
     OPTIMIZE = auto()
     OPTIONS = auto()
@@ -320,6 +323,7 @@ class Tokenizer:
         "LIMIT": TokenType.LIMIT,
         "NOT": TokenType.NOT,
         "NULL": TokenType.NULL,
+        "OFFSET": TokenType.OFFSET,
         "ON": TokenType.ON,
         "OPTIMIZE": TokenType.OPTIMIZE,
         "OPTIONS": TokenType.OPTIONS,
@@ -397,9 +401,11 @@ class Tokenizer:
         "STRING": TokenType.TEXT,
         "TEXT": TokenType.TEXT,
         "BINARY": TokenType.BINARY,
+        "BYTEA": TokenType.BINARY,
         "TIMESTAMP": TokenType.TIMESTAMP,
         "TIMESTAMPTZ": TokenType.TIMESTAMPTZ,
         "DATE": TokenType.DATE,
+        "UUID": TokenType.UUID,
     }
 
     WHITE_SPACE = {
